@@ -5,7 +5,11 @@ from python_project_wizard.question.question import Question
 
 class Display(ABC):
     @abstractmethod
-    def prompt(self, question: Question) -> str:
+    def prompt(self, question: Question) -> None:
+        ...
+
+    @abstractmethod
+    def get_input(self) -> str:
         ...
 
     @abstractmethod
